@@ -134,6 +134,9 @@ class BPMService:
         except KeyboardInterrupt:
             self.stop()
 
+    def isConnected(self):
+        return self.eb_calls.is_connected()
+
     def stop(self):
         print("Stopping...")
         self.close()
